---
name: Bug report
about: Create a report to help us improve
title: "[BUG] "
labels: bug
assignees: gwww

---

**Describe the bug**
A clear and concise description of what the bug is. Logs are often useful read [Reporting a Bug](https://github.com/gwww/elkm1#reporting-a-bug).

Simplify your configuration down to the bare minimum if you can. This helps reduce log size.

Simplify the steps you take. Try to remove indirect use of the this platform (through templates, groups, Node RED, etc).

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. ...

**Expected behavior**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Versions (please complete the following information):**
 - ElkM1 version: []
 - Home Assistant version: []

**Additional context**
Add any other context about the problem here.
